/* Generated by ParaType (http://www.paratype.com)*/
/* Font Futura PT Book: Copyright � ParaType, 2012. All rights reserved.*/


@font-face {
	font-family: 'FuturaPTWebBook';
	src: url('FTN45__W.eot');
	src: local('Futura PT Web Book'), local('FuturaPTWebBook'),
	     url('FTN45__W.eot?#iefix') format('embedded-opentype'),
	     url('FTN45__W.woff') format('woff'),
	     url('FTN45__W.ttf') format('truetype'),
	     url('FTN45__W.svg#FuturaPTWeb-Book') format('svg');
	font-weight: normal;
	font-style: normal;
}